@@ -16,7 +16,7 @@
 %                              December 2001                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 2001 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -53,16 +53,19 @@
 #include "MagickCore/image-private.h"
 #include "MagickCore/memory_.h"
 #include "MagickCore/memory-private.h"
-#include "MagickCore/semaphore.h"
 #include "MagickCore/random_.h"
 #include "MagickCore/random-private.h"
 #include "MagickCore/resource_.h"
+#include "MagickCore/semaphore.h"
 #include "MagickCore/signature-private.h"
 #include "MagickCore/string_.h"
 #include "MagickCore/thread_.h"
 #include "MagickCore/thread-private.h"
 #include "MagickCore/utility.h"
 #include "MagickCore/utility-private.h"
+#if defined(MAGICKCORE_HAVE_GETENTROPY)
+#include <sys/random.h>
+#endif
 /*
   Define declarations.
 */
@@ -88,7 +91,7 @@ struct _RandomInfo
   size_t
     i;
 
-  unsigned long
+  MagickSizeType
     seed[4];
 
   double
@@ -182,7 +185,11 @@ MagickExport RandomInfo *AcquireRandomInfo(void)
   random_info->reservoir=AcquireStringInfo(GetSignatureDigestsize(
     random_info->signature_info));
   ResetStringInfo(random_info->reservoir);
-  random_info->normalize=1.0/(~0UL);
+  random_info->normalize=(double) (1.0/(MagickULLConstant(~0) >> 11));
+  random_info->seed[0]=MagickULLConstant(0x76e15d3efefdcbbf);
+  random_info->seed[1]=MagickULLConstant(0xc5004e441c522fb3);
+  random_info->seed[2]=MagickULLConstant(0x77710069854ee241);
+  random_info->seed[3]=MagickULLConstant(0x39109bb02acbe635);
   random_info->secret_key=secret_key;
   random_info->protocol_major=RandomProtocolMajorVersion;
   random_info->protocol_minor=RandomProtocolMinorVersion;
@@ -219,9 +226,9 @@ MagickExport RandomInfo *AcquireRandomInfo(void)
   */
   if (random_info->secret_key == ~0UL)
     {
-      key=GetRandomKey(random_info,sizeof(random_info->secret_key));
+      key=GetRandomKey(random_info,sizeof(random_info->seed));
       (void) memcpy(random_info->seed,GetStringInfoDatum(key),
-        GetStringInfoLength(key));
+        sizeof(random_info->seed));
       key=DestroyStringInfo(key);
     }
   else
@@ -237,16 +244,10 @@ MagickExport RandomInfo *AcquireRandomInfo(void)
       FinalizeSignature(signature_info);
       digest=GetSignatureDigest(signature_info);
       (void) memcpy(random_info->seed,GetStringInfoDatum(digest),
-        MagickMin(GetSignatureDigestsize(signature_info),
-        sizeof(*random_info->seed)));
+        MagickMin((size_t) GetSignatureDigestsize(signature_info),
+        sizeof(random_info->seed)));
       signature_info=DestroySignatureInfo(signature_info);
     }
-  random_info->seed[1]=0x50a7f451UL;
-  random_info->seed[2]=0x5365417eUL;
-  random_info->seed[3]=0xc3a4171aUL;
-  (void) GetPseudoRandomValue(random_info);  /* bootstrap pseudo generator */
-  (void) GetPseudoRandomValue(random_info);
-  (void) GetPseudoRandomValue(random_info);
   return(random_info);
 }
 
@@ -275,9 +276,10 @@ MagickExport RandomInfo *AcquireRandomInfo(void)
 */
 MagickExport RandomInfo *DestroyRandomInfo(RandomInfo *random_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(random_info != (RandomInfo *) NULL);
   assert(random_info->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   LockSemaphoreInfo(random_info->semaphore);
   if (random_info->reservoir != (StringInfo *) NULL)
     random_info->reservoir=DestroyStringInfo(random_info->reservoir);
@@ -321,7 +323,7 @@ MagickExport RandomInfo *DestroyRandomInfo(RandomInfo *random_info)
 #if !defined(MAGICKCORE_WINDOWS_SUPPORT)
 static ssize_t ReadRandom(int file,unsigned char *source,size_t length)
 {
-  register unsigned char
+  unsigned char
     *q;
 
   ssize_t
@@ -348,7 +350,7 @@ static ssize_t ReadRandom(int file,unsigned char *source,size_t length)
 
 static StringInfo *GenerateEntropicChaos(RandomInfo *random_info)
 {
-#define MaxEntropyExtent  64
+#define MaxEntropyExtent  64  /* max permitted: 256 */
 
   MagickThreadType
     tid;
@@ -369,6 +371,20 @@ static StringInfo *GenerateEntropicChaos(RandomInfo *random_info)
   */
   entropy=AcquireStringInfo(0);
   LockSemaphoreInfo(random_info->semaphore);
+#if defined(MAGICKCORE_HAVE_GETENTROPY)
+  {
+    int
+      status;
+    
+    SetStringInfoLength(entropy,MaxEntropyExtent);
+    status=getentropy(GetStringInfoDatum(entropy),MaxEntropyExtent);
+    if (status == 0)
+      {
+        UnlockSemaphoreInfo(random_info->semaphore);
+        return(entropy);
+      }
+  }
+#endif
   chaos=AcquireStringInfo(sizeof(unsigned char *));
   SetStringInfoDatum(chaos,(unsigned char *) &entropy);
   ConcatenateStringInfo(entropy,chaos);
@@ -414,8 +430,8 @@ static StringInfo *GenerateEntropicChaos(RandomInfo *random_info)
 
     if (gettimeofday(&timer,(struct timezone *) NULL) == 0)
       {
-        seconds=timer.tv_sec;
-        nanoseconds=1000UL*timer.tv_usec;
+        seconds=(size_t) timer.tv_sec;
+        nanoseconds=(size_t) (1000UL*timer.tv_usec);
       }
   }
 #endif
@@ -453,51 +469,25 @@ static StringInfo *GenerateEntropicChaos(RandomInfo *random_info)
   SetStringInfoLength(chaos,sizeof(nanoseconds));
   SetStringInfoDatum(chaos,(unsigned char *) &nanoseconds);
   ConcatenateStringInfo(entropy,chaos);
-#if defined(MAGICKCORE_HAVE_MKSTEMP)
-  {
-    char
-      path[MagickPathExtent];
-
-    int
-      file;
-
-    (void) strcpy(path,"XXXXXX");
-    file=mkstemp(path);
-    if (file != -1)
-      {
-#if defined(MAGICKCORE_HAVE_FCHMOD)
-        (void) fchmod(file,0600);
-#endif
-#if defined(__OS2__)
-        setmode(file,O_BINARY);
-#endif
-        (void) close(file);
-      }
-    (void) remove_utf8(path);
-    SetStringInfoLength(chaos,strlen(path));
-    SetStringInfoDatum(chaos,(unsigned char *) path);
-    ConcatenateStringInfo(entropy,chaos);
-  }
-#endif
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
   {
     double
-      seconds;
+      nt_seconds;
 
     LARGE_INTEGER
-      nanoseconds;
+      nt_nanoseconds;
 
     /*
-      Not crytographically strong but better than nothing.
+      Not cryptographically strong but better than nothing.
     */
-    seconds=NTElapsedTime()+NTUserTime();
-    SetStringInfoLength(chaos,sizeof(seconds));
-    SetStringInfoDatum(chaos,(unsigned char *) &seconds);
+    nt_seconds=NTElapsedTime()+NTUserTime();
+    SetStringInfoLength(chaos,sizeof(nt_seconds));
+    SetStringInfoDatum(chaos,(unsigned char *) &nt_seconds);
     ConcatenateStringInfo(entropy,chaos);
-    if (QueryPerformanceCounter(&nanoseconds) != 0)
+    if (QueryPerformanceCounter(&nt_nanoseconds) != 0)
       {
-        SetStringInfoLength(chaos,sizeof(nanoseconds));
-        SetStringInfoDatum(chaos,(unsigned char *) &nanoseconds);
+        SetStringInfoLength(chaos,sizeof(nt_nanoseconds));
+        SetStringInfoDatum(chaos,(unsigned char *) &nt_nanoseconds);
         ConcatenateStringInfo(entropy,chaos);
       }
     /*
@@ -522,15 +512,15 @@ static StringInfo *GenerateEntropicChaos(RandomInfo *random_info)
       *device;
 
     /*
-      Not crytographically strong but better than nothing.
+      Not cryptographically strong but better than nothing.
     */
     if (environ != (char **) NULL)
       {
-        register ssize_t
+        ssize_t
           i;
 
         /*
-          Squeeze some entropy from the sometimes unpredicatble environment.
+          Squeeze some entropy from the sometimes unpredictable environment.
         */
         for (i=0; environ[i] != (char *) NULL; i++)
         {
@@ -596,9 +586,9 @@ static StringInfo *GenerateEntropicChaos(RandomInfo *random_info)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetPseudoRandomValue() return a non-negative double-precision floating-point
-%  value uniformly distributed over the interval [0.0, 1.0) with a 2 to the
-%  128th-1 period.
+%  GetPseudoRandomValue() is a Xoshiro generator that returns a non-negative
+%  double-precision floating-point value uniformly distributed over the
+%  interval [0.0, 1.0) with a 2 to the 256th-1 period.
 %
 %  The format of the GetPseudoRandomValue method is:
 %
@@ -609,24 +599,22 @@ static StringInfo *GenerateEntropicChaos(RandomInfo *random_info)
 %    o random_info: the random info.
 %
 */
-MagickExport double GetPseudoRandomValue(RandomInfo *random_info)
+MagickExport double GetPseudoRandomValue(
+  RandomInfo *magick_restrict random_info)
 {
-  register unsigned long
-    *seed;
+#define RandomROTL(x,k) (((x) << (k)) | ((x) >> (64-(k))))
 
-  unsigned long
-    alpha;
+  const MagickSizeType
+    alpha = (random_info->seed[1] << 17),
+    value = (random_info->seed[0]+random_info->seed[3]);
 
-  seed=random_info->seed;
-  do
-  {
-    alpha=(unsigned long) (seed[1] ^ (seed[1] << 11));
-    seed[1]=seed[2];
-    seed[2]=seed[3];
-    seed[3]=seed[0];
-    seed[0]=(seed[0] ^ (seed[0] >> 19)) ^ (alpha ^ (alpha >> 8));
-  } while (seed[0] == ~0UL);
-  return(random_info->normalize*seed[0]);
+  random_info->seed[2]^=random_info->seed[0];
+  random_info->seed[3]^=random_info->seed[1];
+  random_info->seed[1]^=random_info->seed[2];
+  random_info->seed[0]^=random_info->seed[3];
+  random_info->seed[2]^=alpha;
+  random_info->seed[3]=RandomROTL(random_info->seed[3],45);
+  return((double) ((value >> 11)*random_info->normalize));
 }
 
 /*
@@ -682,7 +670,7 @@ MagickPrivate double GetRandomInfoNormalize(const RandomInfo *random_info)
 MagickPrivate unsigned long *GetRandomInfoSeed(RandomInfo *random_info)
 {
   assert(random_info != (RandomInfo *) NULL);
-  return(random_info->seed);
+  return((unsigned long *) random_info->seed);
 }
 
 /*
@@ -732,7 +720,7 @@ MagickExport StringInfo *GetRandomKey(RandomInfo *random_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetRandomSecretKey() returns the random secet key.
+%  GetRandomSecretKey() returns the random secret key.
 %
 %  The format of the GetRandomSecretKey method is:
 %
@@ -861,7 +849,7 @@ MagickPrivate void RandomComponentTerminus(void)
 
 static inline void IncrementRandomNonce(StringInfo *nonce)
 {
-  register ssize_t
+  ssize_t
     i;
 
   unsigned char
@@ -880,10 +868,10 @@ static inline void IncrementRandomNonce(StringInfo *nonce)
 MagickExport void SetRandomKey(RandomInfo *random_info,const size_t length,
   unsigned char *key)
 {
-  register size_t
+  size_t
     i;
 
-  register unsigned char
+  unsigned char
     *p;
 
   SignatureInfo
