@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -64,7 +64,7 @@
 #include "MagickCore/string_.h"
 
 /*
-  Typedef declaractions.
+  Typedef declarations.
 */
 struct _StreamInfo
 {
@@ -128,9 +128,6 @@ static Quantum
 }
 #endif
 
-static ssize_t
-  cache_anonymous_memory = (-1);
-
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -201,14 +198,20 @@ MagickExport StreamInfo *AcquireStreamInfo(const ImageInfo *image_info,
 static inline void RelinquishStreamPixels(CacheInfo *cache_info)
 {
   assert(cache_info != (CacheInfo *) NULL);
-  if (cache_info->mapped == MagickFalse)
-    (void) RelinquishAlignedMemory(cache_info->pixels);
-  else
-    (void) UnmapBlob(cache_info->pixels,(size_t) cache_info->length);
-  cache_info->pixels=(Quantum *) NULL;
+  if (cache_info->pixels != (Quantum *) NULL)
+    {
+      if (cache_info->mapped == MagickFalse)
+        cache_info->pixels=(Quantum *) RelinquishAlignedMemory(
+          cache_info->pixels);
+      else
+        {
+          (void) UnmapBlob(cache_info->pixels,(size_t) cache_info->length);
+          cache_info->pixels=(Quantum *) NULL;
+        }
+    }
+  cache_info->mapped=MagickFalse;
   cache_info->metacontent=(void *) NULL;
   cache_info->length=0;
-  cache_info->mapped=MagickFalse;
 }
 
 static void DestroyPixelStream(Image *image)
@@ -221,7 +224,7 @@ static void DestroyPixelStream(Image *image)
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
   assert(cache_info->signature == MagickCoreSignature);
@@ -269,9 +272,10 @@ static void DestroyPixelStream(Image *image)
 */
 MagickExport StreamInfo *DestroyStreamInfo(StreamInfo *stream_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(stream_info != (StreamInfo *) NULL);
   assert(stream_info->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   if (stream_info->map != (char *) NULL)
     stream_info->map=DestroyString(stream_info->map);
   if (stream_info->pixels != (unsigned char *) NULL)
@@ -320,7 +324,7 @@ static void *GetAuthenticMetacontentFromStream(const Image *image)
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
   assert(cache_info->signature == MagickCoreSignature);
@@ -368,7 +372,7 @@ static Quantum *GetAuthenticPixelsStream(Image *image,const ssize_t x,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   pixels=QueueAuthenticPixelsStream(image,x,y,columns,rows,exception);
   return(pixels);
@@ -404,7 +408,7 @@ static Quantum *GetAuthenticPixelsFromStream(const Image *image)
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
   assert(cache_info->signature == MagickCoreSignature);
@@ -445,10 +449,10 @@ static Quantum *GetAuthenticPixelsFromStream(const Image *image)
 static MagickBooleanType GetOneAuthenticPixelFromStream(Image *image,
   const ssize_t x,const ssize_t y,Quantum *pixel,ExceptionInfo *exception)
 {
-  register Quantum
+  Quantum
     *p;
 
-  register ssize_t
+  ssize_t
     i;
 
   assert(image != (Image *) NULL);
@@ -512,7 +516,7 @@ static MagickBooleanType GetOneVirtualPixelFromStream(const Image *image,
   const Quantum
     *p;
 
-  register ssize_t
+  ssize_t
     i;
 
   assert(image != (Image *) NULL);
@@ -598,7 +602,7 @@ static const Quantum *GetVirtualPixelsStream(const Image *image)
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
   assert(cache_info->signature == MagickCoreSignature);
@@ -636,7 +640,7 @@ static const void *GetVirtualMetacontentFromStream(const Image *image)
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
   assert(cache_info->signature == MagickCoreSignature);
@@ -684,44 +688,11 @@ static inline MagickBooleanType AcquireStreamPixels(CacheInfo *cache_info,
 {
   if (cache_info->length != (MagickSizeType) ((size_t) cache_info->length))
     return(MagickFalse);
-  if (cache_anonymous_memory < 0)
-    {
-      char
-        *value;
-
-      /*
-        Does the security policy require anonymous mapping for pixel cache?
-      */
-      cache_anonymous_memory=0;
-      value=GetPolicyValue("pixel-cache-memory");
-      if (value == (char *) NULL)
-        value=GetPolicyValue("cache:memory-map");
-      if (LocaleCompare(value,"anonymous") == 0)
-        {
-#if defined(MAGICKCORE_HAVE_MMAP) && defined(MAP_ANONYMOUS)
-          cache_anonymous_memory=1;
-#else
-          (void) ThrowMagickException(exception,GetMagickModule(),
-            MissingDelegateError,"DelegateLibrarySupportNotBuiltIn",
-            "'%s' (policy requires anonymous memory mapping)",
-            cache_info->filename);
-#endif
-        }
-      value=DestroyString(value);
-    }
-   if (cache_anonymous_memory <= 0)
-     {
-       cache_info->mapped=MagickFalse;
-       cache_info->pixels=(Quantum *) MagickAssumeAligned(
-         AcquireAlignedMemory(1,(size_t) cache_info->length));
-     }
-   else
-     {
-       cache_info->mapped=MagickTrue;
-       cache_info->pixels=(Quantum *) MapBlob(-1,IOMode,0,(size_t)
-         cache_info->length);
-     }
-  if (cache_info->pixels == (Quantum *) NULL)
+  cache_info->pixels=(Quantum *) MagickAssumeAligned(AcquireAlignedMemory(1,
+    (size_t) cache_info->length));
+  if (cache_info->pixels != (Quantum *) NULL)
+    (void) memset(cache_info->pixels,0,(size_t) cache_info->length);
+  else
     {
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",
@@ -755,7 +726,7 @@ static const Quantum *GetVirtualPixelStream(const Image *image,
   */
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((x < 0) || (y < 0) ||
       ((x+(ssize_t) columns) > (ssize_t) image->columns) ||
@@ -878,6 +849,37 @@ MagickExport MagickBooleanType OpenStream(const ImageInfo *image_info,
 %      pixels.
 %
 */
+
+static inline MagickBooleanType ValidatePixelCacheMorphology(
+  const Image *magick_restrict image)
+{
+  const CacheInfo
+    *magick_restrict cache_info;
+
+  const PixelChannelMap
+    *magick_restrict p,
+    *magick_restrict q;
+
+  /*
+    Does the image match the pixel cache morphology?
+  */
+  cache_info=(CacheInfo *) image->cache;
+  p=image->channel_map;
+  q=cache_info->channel_map;
+  if ((image->storage_class != cache_info->storage_class) ||
+      (image->colorspace != cache_info->colorspace) ||
+      (image->alpha_trait != cache_info->alpha_trait) ||
+      (image->channels != cache_info->channels) ||
+      (image->columns != cache_info->columns) ||
+      (image->rows != cache_info->rows) ||
+      (image->number_channels != cache_info->number_channels) ||
+      (memcmp(p,q,image->number_channels*sizeof(*p)) != 0) ||
+      (image->metacontent_extent != cache_info->metacontent_extent) ||
+      (cache_info->nexus_info == (NexusInfo **) NULL))
+    return(MagickFalse);
+  return(MagickTrue);
+}
+
 static Quantum *QueueAuthenticPixelsStream(Image *image,const ssize_t x,
   const ssize_t y,const size_t columns,const size_t rows,
   ExceptionInfo *exception)
@@ -901,10 +903,9 @@ static Quantum *QueueAuthenticPixelsStream(Image *image,const ssize_t x,
     Validate pixel cache geometry.
   */
   assert(image != (Image *) NULL);
-  if ((x < 0) || (y < 0) ||
-      ((x+(ssize_t) columns) > (ssize_t) image->columns) ||
-      ((y+(ssize_t) rows) > (ssize_t) image->rows) ||
-      (columns == 0) || (rows == 0))
+  if ((image->columns == 0) || (image->rows == 0) || (x < 0) ||
+      (y < 0) || (x >= (ssize_t) image->columns) ||
+      (y >= (ssize_t) image->rows))
     {
       (void) ThrowMagickException(exception,GetMagickModule(),StreamError,
         "ImageDoesNotContainTheStreamGeometry","`%s'",image->filename);
@@ -919,16 +920,20 @@ static Quantum *QueueAuthenticPixelsStream(Image *image,const ssize_t x,
     }
   cache_info=(CacheInfo *) image->cache;
   assert(cache_info->signature == MagickCoreSignature);
-  if ((image->storage_class != GetPixelCacheStorageClass(image->cache)) ||
-      (image->colorspace != GetPixelCacheColorspace(image->cache)))
+  if (ValidatePixelCacheMorphology(image) == MagickFalse)
     {
-      if (GetPixelCacheStorageClass(image->cache) == UndefinedClass)
+      if (cache_info->storage_class == UndefinedClass)
         (void) stream_handler(image,(const void *) NULL,(size_t)
           cache_info->columns);
       cache_info->storage_class=image->storage_class;
       cache_info->colorspace=image->colorspace;
+      cache_info->alpha_trait=image->alpha_trait;
+      cache_info->channels=image->channels;
       cache_info->columns=image->columns;
       cache_info->rows=image->rows;
+      cache_info->number_channels=image->number_channels;
+      InitializePixelChannelMap(image);
+      ResetPixelCacheChannels(image);
       image->cache=cache_info;
     }
   /*
@@ -1016,11 +1021,11 @@ MagickExport Image *ReadStream(const ImageInfo *image_info,StreamHandler stream,
   */
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickCoreSignature);
-  if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   read_info=CloneImageInfo(image_info);
   read_info->cache=AcquirePixelCache(0);
   GetPixelCacheMethods(&cache_methods);
@@ -1070,7 +1075,6 @@ MagickExport Image *ReadStream(const ImageInfo *image_info,StreamHandler stream,
 */
 MagickPrivate void ResetStreamAnonymousMemory(void)
 {
-  cache_anonymous_memory=0;
 }
 
 /*
@@ -1153,7 +1157,7 @@ MagickExport void SetStreamInfoMap(StreamInfo *stream_info,const char *map)
 %  The format of the SetStreamInfoStorageType method is:
 %
 %      void SetStreamInfoStorageType(StreamInfo *stream_info,
-%        const StoreageType *storage_type)
+%        const StorageType *storage_type)
 %
 %  A description of each parameter follows:
 %
@@ -1304,12 +1308,12 @@ MagickExport Image *StreamImage(const ImageInfo *image_info,
 
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickCoreSignature);
-  if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      image_info->filename);
   assert(stream_info != (StreamInfo *) NULL);
   assert(stream_info->signature == MagickCoreSignature);
   assert(exception != (ExceptionInfo *) NULL);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   read_info=CloneImageInfo(image_info);
   stream_info->image_info=image_info;
   stream_info->quantum_info=AcquireQuantumInfo(image_info,(Image *) NULL);
@@ -1367,10 +1371,10 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
   QuantumType
     *quantum_map;
 
-  register const Quantum
+  const Quantum
     *p;
 
-  register ssize_t
+  ssize_t
     i,
     x;
 
@@ -1381,7 +1385,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
   assert(stream_info->signature == MagickCoreSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   length=strlen(stream_info->map);
   quantum_map=(QuantumType *) AcquireQuantumMemory(length,sizeof(*quantum_map));
@@ -1496,7 +1500,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
   {
     case CharPixel:
     {
-      register unsigned char
+      unsigned char
         *q;
 
       q=(unsigned char *) stream_info->pixels;
@@ -1580,7 +1584,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=ScaleQuantumToChar(GetPixelRed(image,p));
             *q++=ScaleQuantumToChar(GetPixelGreen(image,p));
             *q++=ScaleQuantumToChar(GetPixelBlue(image,p));
-            *q++=ScaleQuantumToChar((Quantum) (GetPixelAlpha(image,p)));
+            *q++=ScaleQuantumToChar(GetPixelAlpha(image,p));
             p+=GetPixelChannels(image);
           }
           break;
@@ -1630,12 +1634,12 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             }
             case AlphaQuantum:
             {
-              *q=ScaleQuantumToChar((Quantum) (GetPixelAlpha(image,p)));
+              *q=ScaleQuantumToChar(GetPixelAlpha(image,p));
               break;
             }
             case OpacityQuantum:
             {
-              *q=ScaleQuantumToChar(GetPixelAlpha(image,p));
+              *q=ScaleQuantumToChar(GetPixelOpacity(image,p));
               break;
             }
             case BlackQuantum:
@@ -1660,7 +1664,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
     }
     case DoublePixel:
     {
-      register double
+      double
         *q;
 
       q=(double *) stream_info->pixels;
@@ -1824,7 +1828,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             }
             case OpacityQuantum:
             {
-              *q=(double) ((QuantumScale*GetPixelAlpha(image,p))*
+              *q=(double) ((QuantumScale*GetPixelOpacity(image,p))*
                 quantum_info->scale+quantum_info->minimum);
               break;
             }
@@ -1852,7 +1856,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
     }
     case FloatPixel:
     {
-      register float
+      float
         *q;
 
       q=(float *) stream_info->pixels;
@@ -1886,7 +1890,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
               quantum_info->scale+quantum_info->minimum);
             *q++=(float) ((QuantumScale*GetPixelRed(image,p))*
               quantum_info->scale+quantum_info->minimum);
-            *q++=(float) ((QuantumScale*(Quantum) (GetPixelAlpha(image,p)))*
+            *q++=(float) ((QuantumScale*GetPixelAlpha(image,p))*
               quantum_info->scale+quantum_info->minimum);
             p+=GetPixelChannels(image);
           }
@@ -2016,7 +2020,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             }
             case OpacityQuantum:
             {
-              *q=(float) ((QuantumScale*GetPixelAlpha(image,p))*
+              *q=(float) ((QuantumScale*GetPixelOpacity(image,p))*
                 quantum_info->scale+quantum_info->minimum);
               break;
             }
@@ -2044,7 +2048,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
     }
     case LongPixel:
     {
-      register unsigned int
+      unsigned int
         *q;
 
       q=(unsigned int *) stream_info->pixels;
@@ -2072,7 +2076,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=ScaleQuantumToLong(GetPixelBlue(image,p));
             *q++=ScaleQuantumToLong(GetPixelGreen(image,p));
             *q++=ScaleQuantumToLong(GetPixelRed(image,p));
-            *q++=ScaleQuantumToLong((Quantum) (GetPixelAlpha(image,p)));
+            *q++=ScaleQuantumToLong(GetPixelAlpha(image,p));
             p+=GetPixelChannels(image);
           }
           break;
@@ -2128,7 +2132,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=ScaleQuantumToLong(GetPixelRed(image,p));
             *q++=ScaleQuantumToLong(GetPixelGreen(image,p));
             *q++=ScaleQuantumToLong(GetPixelBlue(image,p));
-            *q++=ScaleQuantumToLong((Quantum) (GetPixelAlpha(image,p)));
+            *q++=ScaleQuantumToLong(GetPixelAlpha(image,p));
             p+=GetPixelChannels(image);
           }
           break;
@@ -2178,12 +2182,12 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             }
             case AlphaQuantum:
             {
-              *q=ScaleQuantumToLong((Quantum) (GetPixelAlpha(image,p)));
+              *q=ScaleQuantumToLong(GetPixelAlpha(image,p));
               break;
             }
             case OpacityQuantum:
             {
-              *q=ScaleQuantumToLong(GetPixelAlpha(image,p));
+              *q=ScaleQuantumToLong(GetPixelOpacity(image,p));
               break;
             }
             case BlackQuantum:
@@ -2208,7 +2212,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
     }
     case LongLongPixel:
     {
-      register MagickSizeType
+      MagickSizeType
         *q;
 
       q=(MagickSizeType *) stream_info->pixels;
@@ -2348,7 +2352,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             }
             case OpacityQuantum:
             {
-              *q=ScaleQuantumToLongLong(GetPixelAlpha(image,p));
+              *q=ScaleQuantumToLongLong(GetPixelOpacity(image,p));
               break;
             }
             case BlackQuantum:
@@ -2374,7 +2378,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
     }
     case QuantumPixel:
     {
-      register Quantum
+      Quantum
         *q;
 
       q=(Quantum *) stream_info->pixels;
@@ -2417,7 +2421,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=GetPixelBlue(image,p);
             *q++=GetPixelGreen(image,p);
             *q++=GetPixelRed(image,p);
-            *q++=0;
+            *q++=(Quantum) 0;
             p+=GetPixelChannels(image);
           }
           break;
@@ -2473,7 +2477,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=GetPixelRed(image,p);
             *q++=GetPixelGreen(image,p);
             *q++=GetPixelBlue(image,p);
-            *q++=0U;
+            *q++=(Quantum) 0;
             p+=GetPixelChannels(image);
           }
           break;
@@ -2508,12 +2512,12 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             }
             case AlphaQuantum:
             {
-              *q=(Quantum) (GetPixelAlpha(image,p));
+              *q=GetPixelAlpha(image,p);
               break;
             }
             case OpacityQuantum:
             {
-              *q=GetPixelAlpha(image,p);
+              *q=GetPixelOpacity(image,p);
               break;
             }
             case BlackQuantum:
@@ -2528,7 +2532,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
               break;
             }
             default:
-              *q=0;
+              *q=(Quantum) 0;
           }
           q++;
         }
@@ -2538,7 +2542,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
     }
     case ShortPixel:
     {
-      register unsigned short
+      unsigned short
         *q;
 
       q=(unsigned short *) stream_info->pixels;
@@ -2566,7 +2570,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=ScaleQuantumToShort(GetPixelBlue(image,p));
             *q++=ScaleQuantumToShort(GetPixelGreen(image,p));
             *q++=ScaleQuantumToShort(GetPixelRed(image,p));
-            *q++=ScaleQuantumToShort((Quantum) (GetPixelAlpha(image,p)));
+            *q++=ScaleQuantumToShort(GetPixelAlpha(image,p));
             p+=GetPixelChannels(image);
           }
           break;
@@ -2623,7 +2627,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=ScaleQuantumToShort(GetPixelRed(image,p));
             *q++=ScaleQuantumToShort(GetPixelGreen(image,p));
             *q++=ScaleQuantumToShort(GetPixelBlue(image,p));
-            *q++=ScaleQuantumToShort((Quantum) (GetPixelAlpha(image,p)));
+            *q++=ScaleQuantumToShort(GetPixelAlpha(image,p));
             p+=GetPixelChannels(image);
           }
           break;
@@ -2678,7 +2682,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             }
             case OpacityQuantum:
             {
-              *q=ScaleQuantumToShort(GetPixelAlpha(image,p));
+              *q=ScaleQuantumToShort(GetPixelOpacity(image,p));
               break;
             }
             case BlackQuantum:
@@ -2754,7 +2758,7 @@ static MagickBooleanType SyncAuthenticPixelsStream(Image *image,
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
   assert(cache_info->signature == MagickCoreSignature);
@@ -2808,7 +2812,7 @@ MagickExport MagickBooleanType WriteStream(const ImageInfo *image_info,
 
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickCoreSignature);
-  if (image_info->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   assert(image != (Image *) NULL);
