@@ -445,8 +445,7 @@ static boolean ReadProfileData(j_decompress_ptr jpeg_info,const int index,
     }
   if (client_info->profiles[index] == (StringInfo *) NULL)
     {
-      client_info->profiles[index]=BlobToStringInfo((const void *) NULL,
-        length);
+      client_info->profiles[index]=BlobToStringInfo((const void *) NULL,length);
       if (client_info->profiles[index] == (StringInfo *) NULL)
         {
           (void) ThrowMagickException(exception,GetMagickModule(),
@@ -461,8 +460,7 @@ static boolean ReadProfileData(j_decompress_ptr jpeg_info,const int index,
         current_length;
 
       current_length=GetStringInfoLength(client_info->profiles[index]);
-      SetStringInfoLength(client_info->profiles[index],current_length+
-        length);
+      SetStringInfoLength(client_info->profiles[index],current_length+length);
       p=GetStringInfoDatum(client_info->profiles[index])+current_length;
     }
   for (i=0; i < (ssize_t) length; i++)
@@ -879,7 +877,7 @@ static void JPEGSetImageQuality(struct jpeg_decompress_struct *jpeg_info,
             if ((qvalue < hash[i]) && (sum < sums[i]))
               continue;
             if (((qvalue <= hash[i]) && (sum <= sums[i])) || (i >= 50))
-              image->quality=(size_t)i+1;
+              image->quality=(size_t) i+1;
             if (image->debug != MagickFalse)
               (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                 "Quality: %.20g (%s)",(double) i+1,(qvalue <= hash[i]) &&
@@ -2124,7 +2122,7 @@ static void WriteProfiles(j_compress_ptr jpeg_info,Image *image,
         }
       }
    if ((LocaleCompare(name,"XMP") == 0) &&
-       (GetStringInfoLength(profile) < (65533 - sizeof(xmp_namespace))))
+       (GetStringInfoLength(profile) < (65533-sizeof(xmp_namespace))))
       {
         StringInfo
           *xmp_profile;
@@ -2799,8 +2797,10 @@ static MagickBooleanType WriteJPEGImage_(const ImageInfo *image_info,
       return(MagickFalse);
     }
   scanline[0]=(JSAMPROW) jpeg_pixels;
-  scale=65535/(unsigned short) GetQuantumRange((size_t)
-    jpeg_info->data_precision);
+  scale=0;
+  if (GetQuantumRange((size_t) jpeg_info->data_precision) != 0)
+    scale=65535/(unsigned short) GetQuantumRange((size_t)
+      jpeg_info->data_precision);
   if (scale == 0)
     scale=1;
   if (jpeg_info->data_precision <= 8)
